[PATCH] D14121: Thumb state not being passed through to LLVM triple when using clang -cc1as

Alexandros Lamprineas via cfe-commits cfe-commits at lists.llvm.org
Tue Oct 27 09:22:03 PDT 2015


labrinea updated this revision to Diff 38552.

http://reviews.llvm.org/D14121

Files:
  lib/Driver/ToolChain.cpp
  test/Driver/arm-ias-Wa.s

Index: test/Driver/arm-ias-Wa.s
===================================================================
--- test/Driver/arm-ias-Wa.s
+++ test/Driver/arm-ias-Wa.s
@@ -62,3 +62,17 @@
 // RUN:   | FileCheck --check-prefix=CHECK-DUP-HDIV %s
 // CHECK-DUP-HDIV: "-target-feature" "-hwdiv-arm"
 // CHECK-DUP-HDIV: "-target-feature" "+hwdiv"
+
+// ========================================================== Triple
+// RUN: %clang -target armv7a-none-eabi -c %s -### 2>&1 \
+// RUN:   | FileCheck -check-prefix=CHECK-A-PROFILE %s
+// CHECK-A-PROFILE: "-triple" "armv7-none--eabi"
+
+// RUN: %clang -target armv7r-none-eabi -c %s -### 2>&1 \
+// RUN:   | FileCheck -check-prefix=CHECK-R-PROFILE %s
+// CHECK-R-PROFILE: "-triple" "armv7r-none--eabi"
+
+// RUN: %clang -target thumbv7m-none-eabi -c %s -### 2>&1 \
+// RUN:   | FileCheck -check-prefix=CHECK-M-PROFILE %s
+// CHECK-M-PROFILE: "-triple" "thumbv7m-none--eabi"
+
Index: lib/Driver/ToolChain.cpp
===================================================================
--- lib/Driver/ToolChain.cpp
+++ lib/Driver/ToolChain.cpp
@@ -23,10 +23,12 @@
 #include "llvm/Support/ErrorHandling.h"
 #include "llvm/Support/FileSystem.h"
 #include "llvm/Support/TargetRegistry.h"
+#include "llvm/Support/TargetParser.h"
 
 using namespace clang::driver;
 using namespace clang::driver::tools;
 using namespace clang;
+using namespace llvm;
 using namespace llvm::opt;
 
 static llvm::opt::Arg *GetRTTIArgument(const ArgList &Args) {
@@ -478,9 +480,10 @@
     else
       ArchName = "arm";
 
-    // Assembly files should start in ARM mode.
-    if (InputType != types::TY_PP_Asm &&
-        Args.hasFlag(options::OPT_mthumb, options::OPT_mno_thumb, ThumbDefault))
+    // Assembly files should start in ARM mode, unless arch is M-profile.
+    if ((ARM::parseArchProfile(Suffix) == ARM::PK_M) ||
+        (InputType != types::TY_PP_Asm &&
+         Args.hasFlag(options::OPT_mthumb, options::OPT_mno_thumb, ThumbDefault)))
     {
       if (IsBigEndian)
         ArchName = "thumbeb";


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D14121.38552.patch
Type: text/x-patch
Size: 2014 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20151027/12a07e17/attachment-0001.bin>


More information about the cfe-commits mailing list